@@ -1,4 +1,4 @@
-# Copyright (c) 2013 Hortonworks, Inc.
+# Copyright (c) 2014 Hortonworks, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,11 +30,10 @@ from sahara.plugins.general import exceptions as ex
 from sahara.plugins.hdp import clusterspec as cs
 from sahara.plugins.hdp import configprovider as cfgprov
 from sahara.plugins.hdp.versions import abstractversionhandler as avm
-from sahara.plugins.hdp.versions.version_1_3_2 import edp_engine
-from sahara.plugins.hdp.versions.version_1_3_2 import services
+from sahara.plugins.hdp.versions.version_2_0_6 import edp_engine
+from sahara.plugins.hdp.versions.version_2_0_6 import services
 from sahara import version
 
-
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
@@ -52,7 +51,7 @@ class VersionHandler(avm.AbstractVersionHandler):
             self.config_provider = cfgprov.ConfigurationProvider(
                 json.load(pkg.resource_stream(
                           version.version_info.package,
-                          'plugins/hdp/versions/version_1_3_2/resources/'
+                          'plugins/hdp/versions/version_2_0_6/resources/'
                           'ambari-config-resource.json')))
 
         return self.config_provider
@@ -75,19 +74,8 @@ class VersionHandler(avm.AbstractVersionHandler):
     def get_cluster_spec(self, cluster, user_inputs,
                          scaled_groups=None, cluster_template=None):
         if cluster_template:
-            cluster_spec = cs.ClusterSpec(cluster_template)
+            cluster_spec = cs.ClusterSpec(cluster_template, '2.0.6')
         else:
-            if scaled_groups:
-                for ng in cluster.node_groups:
-                    ng_id = ng['id']
-                    if (ng_id in scaled_groups and
-                       ng['count'] > scaled_groups[ng_id]):
-                            raise ex.ClusterCannotBeScaled(
-                                cluster.name,
-                                _('The HDP plugin does not support '
-                                  'the decommissioning of nodes '
-                                  'for HDP version 1.3.2'))
-
             cluster_spec = self.get_default_cluster_configuration()
             cluster_spec.create_operational_config(
                 cluster, user_inputs, scaled_groups)
@@ -95,12 +83,12 @@ class VersionHandler(avm.AbstractVersionHandler):
         return cluster_spec
 
     def get_default_cluster_configuration(self):
-        return cs.ClusterSpec(self._get_default_cluster_template())
+        return cs.ClusterSpec(self._get_default_cluster_template(), '2.0.6')
 
     def _get_default_cluster_template(self):
         return pkg.resource_string(
             version.version_info.package,
-            'plugins/hdp/versions/version_1_3_2/resources/'
+            'plugins/hdp/versions/version_2_0_6/resources/'
             'default-cluster.template')
 
     def get_node_processes(self):
@@ -139,38 +127,24 @@ class AmbariClient():
         return {"X-Requested-By": "sahara"}
 
     def _post(self, url, ambari_info, data=None):
-        if data:
-            LOG.debug('AmbariClient:_post call, url = ' + url +
-                      ' data = ' + str(data))
-        else:
-            LOG.debug('AmbariClient:_post call, url = ' + url)
-
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.post(url, data=data,
                             auth=(ambari_info.user, ambari_info.password),
                             headers=self._get_standard_headers())
 
     def _delete(self, url, ambari_info):
-        LOG.debug('AmbariClient:_delete call, url = ' + url)
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.delete(url,
                               auth=(ambari_info.user, ambari_info.password),
                               headers=self._get_standard_headers())
 
     def _put(self, url, ambari_info, data=None):
-        if data:
-            LOG.debug('AmbariClient:_put call, url = ' + url +
-                      ' data = ' + str(data))
-        else:
-            LOG.debug('AmbariClient:_put call, url = ' + url)
-
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         auth = (ambari_info.user, ambari_info.password)
         return session.put(url, data=data, auth=auth,
                            headers=self._get_standard_headers())
 
     def _get(self, url, ambari_info):
-        LOG.debug('AmbariClient:_get call, url = ' + url)
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.get(url, auth=(ambari_info.user, ambari_info.password),
                            headers=self._get_standard_headers())
@@ -183,7 +157,7 @@ class AmbariClient():
                             self.handler.get_version() + '"}}')
 
         if result.status_code != 201:
-            LOG.error(_LE('Create cluster command failed. %s') % result.text)
+            LOG.error(_LE('Create cluster command failed. %s'), result.text)
             raise ex.HadoopProvisionError(
                 _('Failed to add cluster: %s') % result.text)
 
@@ -216,8 +190,8 @@ class AmbariClient():
         for config_name in configs:
             if config_name in existing_configs:
                 if config_name == 'core-site' or config_name == 'global':
-                    existing_version = (
-                        existing_configs[config_name]['tag'].lstrip('v'))
+                    existing_version = (existing_configs[config_name]['tag']
+                                        .lstrip('v'))
                     version = int(existing_version) + 1
                 else:
                     continue
@@ -241,7 +215,8 @@ class AmbariClient():
         services = cluster_spec.services
         add_service_url = 'http://{0}/api/v1/clusters/{1}/services/{2}'
         for service in services:
-            if service.deployed and service.name != 'AMBARI':
+            # Make sure the service is deployed and is managed by Ambari
+            if service.deployed and service.ambari_managed:
                 result = self._post(add_service_url.format(
                     ambari_info.get_address(), name, service.name),
                     ambari_info)
@@ -257,7 +232,8 @@ class AmbariClient():
         add_component_url = ('http://{0}/api/v1/clusters/{1}/services/{'
                              '2}/components/{3}')
         for service in cluster_spec.services:
-            if service.deployed and service.name != 'AMBARI':
+            # Make sure the service is deployed and is managed by Ambari
+            if service.deployed and service.ambari_managed:
                 for component in service.components:
                     result = self._post(add_component_url.format(
                         ambari_info.get_address(), name, service.name,
@@ -292,8 +268,11 @@ class AmbariClient():
             # TODO(jspeidel): ensure that node group exists
             node_group = cluster_spec.node_groups[node_group_name]
             for component in node_group.components:
-                # don't add any AMBARI components
-                if component.find('AMBARI') != 0:
+                # Don't add any AMBARI or HUE components
+                # TODO(rlevas): Pragmatically determine if component is
+                #   managed by Ambari
+                if (component.find('AMBARI') != 0
+                        and component.find('HUE') != 0):
                     result = self._post(add_host_component_url.format(
                         ambari_info.get_address(), name, hostname, component),
                         ambari_info)
@@ -342,6 +321,11 @@ class AmbariClient():
                     ambari_info.get_address(), cluster_name,
                     request_id))
 
+    # Returns the top-level requests API URI
+    def _get_command_request_uri(self, ambari_info, cluster_name):
+        return ('http://{0}/api/v1/clusters/{1}/requests'.format(
+            ambari_info.get_address(), cluster_name))
+
     def _wait_for_async_request(self, request_url, ambari_info):
         started = False
         while not started:
@@ -375,13 +359,13 @@ class AmbariClient():
         if result.status_code != 201 and result.status_code != 202:
             LOG.warning(_LW('Finalizing of Ambari cluster state failed. {0}').
                         format(result.text))
-            raise ex.HadoopProvisionError(_('Unable to finalize Ambari '
-                                            'state.'))
+            raise ex.HadoopProvisionError(
+                _('Unable to finalize Ambari state.'))
 
     def start_services(self, cluster_name, cluster_spec, ambari_info):
         LOG.info(_LI('Starting Hadoop services ...'))
-        LOG.info(_LI('Cluster name: %(cluster_name)s, Ambari server address: '
-                     '%(server_address)s'),
+        LOG.info(_LI('Cluster name: %(cluster_name)s, Ambari server address:'
+                     ' %(server_address)s'),
                  {'cluster_name': cluster_name,
                   'server_address': ambari_info.get_address()})
         start_url = ('http://{0}/api/v1/clusters/{1}/services?ServiceInfo/'
@@ -410,9 +394,9 @@ class AmbariClient():
 
         elif result.status_code != 200:
             LOG.error(
-                _LE('Start command failed. Status: %(status)s, '
-                    'response: %(response)s'),
-                {'status': result.status_code, 'response': result.text})
+                _LE('Start command failed. Status: %(status)s, response: '
+                    '%(response)s'),
+                {'status': result.status_code, 'result': result.text})
             raise ex.HadoopProvisionError(
                 _('Start of Hadoop services failed.'))
 
@@ -439,7 +423,7 @@ class AmbariClient():
             LOG.error(
                 _LE('Command failed. Status: %(status)s, response: '
                     '%(response)s'),
-                {'status': result.status_code, 'response': result.text})
+                {'status': result.status_code, 'result': result.text})
             raise ex.HadoopProvisionError(_('Hadoop/Ambari command failed.'))
 
     def _get_host_list(self, servers):
@@ -526,8 +510,8 @@ class AmbariClient():
                 result = self._get(url, ambari_info)
                 json_result = json.loads(result.text)
 
-                LOG.info(_LI('Registered Hosts: %(current_number)s of '
-                             '%(final_number)s'),
+                LOG.info(_LI('Registered Hosts: %(current_number)s '
+                             'of %(final_number)s'),
                          {'current_number': len(json_result['items']),
                           'final_number': num_hosts})
                 for hosts in json_result['items']:
@@ -556,8 +540,8 @@ class AmbariClient():
             ambari_info.get_address(), user.name)
 
         create_body = ('{{"Users":{{"password":"{0}","roles":"{1}"}} }}'.
-                       format(user.password, '%s' %
-                                             ','.join(map(str, user.groups))))
+                       format(user.password, '%s' % ','.
+                              join(map(str, user.groups))))
 
         result = self._post(user_url, ambari_info, data=create_body)
 
@@ -598,9 +582,115 @@ class AmbariClient():
 
     def decommission_cluster_instances(self, cluster, clusterspec, instances,
                                        ambari_info):
-        raise exc.InvalidException(_('The HDP plugin does not support '
-                                     'the decommissioning of nodes '
-                                     'for HDP version 1.3.2'))
+
+        request_uri = self._get_command_request_uri(ambari_info, cluster.name)
+
+        hosts_to_decommission = []
+        # Decommission HDFS datanodes to avoid loss of data
+        # during decommissioning process
+        for instance in instances:
+            ng_name = instance.node_group.name
+            if "DATANODE" in clusterspec.node_groups[ng_name].components:
+                # determine the instances that include HDFS support
+                hosts_to_decommission.append(instance.fqdn())
+
+        LOG.debug('AmbariClient: hosts_to_decommission = '
+                  + str(hosts_to_decommission))
+
+        # template for request body
+        body_header = ('{"RequestInfo" : { "context": "Decommission DataNode",'
+                       ' "command" : "DECOMMISSION", "service_name" : "HDFS",'
+                       ' "component_name" : "NAMENODE", '
+                       ' "parameters" : { "slave_type" : "DATANODE", ')
+
+        excluded_hosts_request = '"excluded_hosts" : "{0}"'
+
+        # generate comma-separated list of hosts to de-commission
+        list_of_hosts = ",".join(hosts_to_decommission)
+
+        LOG.debug('AmbariClient: list_of_hosts = ' + list_of_hosts)
+
+        # create the request body
+        request_body = (
+            body_header +
+            excluded_hosts_request.format(list_of_hosts)
+            + '}}'
+            + ', "Requests/resource_filters":[{"service_name":"HDFS",'
+            '"component_name":"NAMENODE"}]}')
+
+        LOG.debug('AmbariClient: about to make decommission request, uri = ' +
+                  request_uri)
+        LOG.debug('AmbariClient: about to make decommission request, ' +
+                  'request body  = ' + request_body)
+
+        # ask Ambari to decommission the datanodes
+        result = self._post(request_uri, ambari_info, request_body)
+        if result.status_code != 202:
+            LOG.error(_LE('AmbariClient: error while making decommission post '
+                          'request. Error is = %s'), result.text)
+            raise exc.InvalidException(
+                _('An error occurred while trying to '
+                  'decommission the DataNode instances that are '
+                  'being shut down. '
+                  'Please consult the Ambari server logs on the '
+                  'master node for '
+                  'more information about the failure.'))
+        else:
+            LOG.info(_LI('AmbariClient: decommission post request succeeded!'))
+
+        status_template = ('http://{0}/api/v1/clusters/{1}/hosts/{2}/'
+                           'host_components/{3}')
+
+        # find the host that the NameNode is deployed on
+        name_node_host = clusterspec.determine_component_hosts(
+            'NAMENODE').pop()
+        status_request = status_template.format(
+            ambari_info.get_address(),
+            cluster.name, name_node_host.fqdn(),
+            'NAMENODE')
+
+        LOG.debug('AmbariClient: about to make decommission status request,' +
+                  'uri = ' + status_request)
+
+        count = 0
+        while count < 100 and len(hosts_to_decommission) > 0:
+            LOG.info(_LI('AmbariClient: number of hosts waiting for '
+                         'decommissioning to complete = %s'),
+                     str(len(hosts_to_decommission)))
+
+            result = self._get(status_request, ambari_info)
+            if result.status_code != 200:
+                LOG.error(_LE('AmbariClient: error in making decommission '
+                              'status request, error = %s'), result.text)
+            else:
+                LOG.info(_LI('AmbariClient: decommission status request ok, '
+                             'result = %s'), result.text)
+                json_result = json.loads(result.text)
+                live_nodes = (
+                    json_result['metrics']['dfs']['namenode']['LiveNodes'])
+                # parse out the map of live hosts associated with the NameNode
+                json_result_nodes = json.loads(live_nodes)
+                for node in json_result_nodes.keys():
+                    admin_state = json_result_nodes[node]['adminState']
+                    if admin_state == 'Decommissioned':
+                        LOG.info(_LI('AmbariClient: node = %(node)s is '
+                                     'now in adminState = %(admin_state)s'),
+                                 {'node': node,
+                                  'admin_state': admin_state})
+                        # remove from list, to track which nodes
+                        # are now in Decommissioned state
+                        hosts_to_decommission.remove(node)
+
+            LOG.info(_LI('AmbariClient: sleeping for 5 seconds'))
+            context.sleep(5)
+
+            # increment loop counter
+            count += 1
+
+        if len(hosts_to_decommission) > 0:
+            LOG.error(_LE('AmbariClient: decommissioning process timed-out '
+                          'waiting for nodes to enter "Decommissioned" '
+                          'status.'))
 
     def provision_cluster(self, cluster_spec, servers, ambari_info, name):
         self._add_cluster(ambari_info, name)
