@@ -30,10 +30,40 @@ class VanillaTwoConfigTestCase(base.SaharaTestCase):
             'hadoop_secure_dn_log_dir': '/vol1/hadoop/logs/secure',
             'yarn_log_dir': '/vol1/yarn/logs'
         }
-        self.assertEqual(expected, dirs)
+        self.assertEqual(dirs, expected)
+
+    def test_merge_configs(self):
+        a = {
+            'HDFS': {
+                'param1': 'value1',
+                'param2': 'value2'
+            }
+        }
+        b = {
+            'HDFS': {
+                'param1': 'value3',
+                'param3': 'value4'
+            },
+            'YARN': {
+                'param5': 'value5'
+            }
+        }
+
+        res = c._merge_configs(a, b)
+        expected = {
+            'HDFS': {
+                'param1': 'value3',
+                'param2': 'value2',
+                'param3': 'value4'
+            },
+            'YARN': {
+                'param5': 'value5'
+            }
+        }
+        self.assertEqual(res, expected)
 
 
-class FakeNG(object):
+class FakeNG():
     def __init__(self, storage_paths=None):
         self.paths = storage_paths
 
