@@ -20,6 +20,7 @@ from sahara.tests.unit.service.validation import utils as u
 
 class TestNGTemplateCreateValidation(u.ValidationTestCase):
     def setUp(self):
+        super(TestNGTemplateCreateValidation, self).setUp()
         self._create_object_fun = nt.check_node_group_template_create
         self.scheme = nt.NODE_GROUP_TEMPLATE_SCHEMA
         api.plugin_base.setup_plugins()
@@ -66,7 +67,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'node_processes': []
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'[] is too short')
+                       u'\[\] is too short')
         )
 
     def test_ng_template_create_v_names(self):
@@ -100,9 +101,9 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'node_processes': ['wrong_process']
             },
             bad_req_i=(1, 'INVALID_REFERENCE',
-                       "Plugin supports the following node procesess: "
-                       "['namenode', 'datanode', 'secondarynamenode', "
-                       "'oozie', 'tasktracker', 'jobtracker', 'hiveserver']")
+                       "Plugin supports the following node procesess: ["
+                       "'datanode', 'hiveserver', 'jobtracker', 'namenode', "
+                       "'oozie', 'secondarynamenode', 'tasktracker']")
         )
 
     def test_ng_template_create_v_right(self):
@@ -141,7 +142,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'volumes_per_node': -1
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'-1.0 is less than the minimum of 0')
+                       u'-1(.0)? is less than the minimum of 0')
         )
         self._assert_create_object_validation(
             data={
@@ -153,7 +154,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'volumes_size': 0
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'0.0 is less than the minimum of 1')
+                       u'0(.0)? is less than the minimum of 1')
         )
 
     def test_ng_template_create_v_types(self):
@@ -237,7 +238,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'volumes_per_node': -1
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'-1.0 is less than the minimum of 0')
+                       u'-1(.0)? is less than the minimum of 0')
         )
         self._assert_create_object_validation(
             data={
@@ -249,7 +250,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'volumes_size': 0
             },
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'0.0 is less than the minimum of 1')
+                       u'0(.0)? is less than the minimum of 1')
         )
         self._assert_create_object_validation(
             data={
